=======
History
=======

0.1.0 (2020-06-06)
------------------

* First release on PyPI.

0.1.1 (2020-06-06)
------------------

* Removed python 3.5 from supported versions
* Removed useless test files
* Added encoding
